::  ====================================
::  GUILD WARS 2 LAUNCHER for Windows 10
::  Version : 4.1
::  Date : 2020.12.29
::  ====================================


::  ===============================
::  EDIT VARIABLES BEYOND THIS LINE
::  ===============================

::  You must also edit the file 'GuildWars2_UpdateArcDps.cmd'
::  to also include the location of the Guild Wars 2 folder!

::  [== FOLDER OF GUILD WARS 2 ==]
::  Indicate here the complete path of the game folder (WITHOUT THE LAST \ )
::  Only change the value after the = and no use quote mark!

set gw2Path=C:\Program Files (x86)\Guild Wars 2

::  [== EXECUTABLE OF GUILD WARS 2 ==]
::  Indicate here the name of the executable of the game (WITH THE .EXE)
::  Only change the value after the = sign without quotes!
::  ArcDPS only works with the 64-bit version of the game

set gw2Exe=Gw2-64.exe

::  ====== ARGUMENTS (OPTIONAL) ======
::  Add all the command-line arguments you need here, enclosed in quotation marks.
::  Separate the arguments with a comma and a space.
::  Leave "" empty if no arguments
::  See the list of possible arguments: https://wiki.guildwars2.com/wiki/Command_line_arguments

set cmdLine=""

::  ==============================
::  DO NOT CHANGE BEYOND THIS LINE
::  ==============================


:Global
@echo off
color 70
title Guild Wars 2 Launcher Wizard

:Menu
cls
echo.
echo.[32m GUILD WARS 2 LAUNCHER WIZARD
echo. ----------------------------[30;47m
echo.
echo. 1. Starting WITH Updating ArcDPS
echo. 2. Starting WITHOUT Updating ArcDPS
echo.[33m    -----------
echo.    MAINTENANCE
echo.    -----------[30;47m
echo. 3. Clear temporary files from Guild Wars 2
echo. 4. Clear the Guild Wars 2 Client Cache
echo. 5. Perform a diagnostic of the computer
echo. 6. Analyze and repair game files
echo.    -----------
echo. 0. [31mClose[30;47m
echo.
echo. ---------------------
choice /c 1234560 /n /m "> Choose the start option : "
if %errorlevel% == 1 goto Guildwars2_ArcDPS_Update
if %errorlevel% == 2 goto Guildwars2_ArcDPS_NoCheck
if %errorlevel% == 3 goto Guildwars2_Cache
if %errorlevel% == 4 goto Guildwars2_Client
if %errorlevel% == 5 goto Guildwars2_Diagnostic
if %errorlevel% == 6 goto Guildwars2_Repair
if %errorlevel% == 7 goto Close
goto Menu

:Guildwars2_ArcDPS_Update
cls
echo.
echo. [32m------------------------------------------
echo. Starting Guild Wars 2 WITH Updating ArcDPS
echo. ------------------------------------------[30;47m
echo.
if exist "%gw2Path%\GuildWars2_UpdateArcDps.cmd" (
    call "%gw2Path%\GuildWars2_UpdateArcDps.cmd"
    goto Close
) else (
    echo. [31mFile "GuildWars2_UpdateArcDps.cmd" is not found ![30;47m
    ping 127.0.0.1 -n 2 >nul 2>&1
    echo. Starting the game without ArcDPS version control ...
    ping 127.0.0.1 -n 2 >nul 2>&1
    tasklist | findstr /c:%gw2Exe% >nul
    if %errorlevel% == 0 (
        echo. Guild Wars 2 is already running !
        ping 127.0.0.1 -n 2 >nul 2>&1
        goto Close
    ) else (
        echo. Starting Guild Wars 2 ...
        start "Guild Wars 2" "%gw2Path%\%gw2Exe%" %cmdLine%
        goto Close
    )
)

:Guildwars2_ArcDPS_NoCheck
cls
echo.
echo. [32m---------------------------------------------
echo. Starting Guild Wars 2 WITHOUT Updating ArcDPS
echo. ---------------------------------------------[30;47m
echo.
tasklist | findstr /c:%gw2Exe% >nul
if %errorlevel% == 0 (
    echo. Guild Wars 2 is already running !
    ping 127.0.0.1 -n 2 >nul 2>&1
    goto Close
)
echo. Starting Guild Wars 2 ...
ping 127.0.0.1 -n 2 >nul 2>&1
start "Guild Wars 2" "%gw2Path%\%gw2Exe%" %cmdLine%
goto Close

:Guildwars2_Cache
cls
echo.
echo. [33m---------------------------------------
echo. Clear temporary files from Guild Wars 2
echo. ---------------------------------------[30;47m
echo.
echo. [31m/!\ If the game is in use, it will be closed ![30;47m
echo.
echo. Only temporary files related to Guild Wars 2 will be deleted
echo.
echo. Location of files :
echo. %Temp%\gw2cache-{RANDOM NUMBERS}
echo.
choice /c YN /m "> Confirm deletion of temporary files ? "
if %errorlevel% == 1 goto Delete_Cache
if %errorlevel% == 2 goto Menu
:Delete_Cache
echo.
tasklist | findstr /c:%gw2Exe% >nul
if %errorlevel% == 0 (
    echo. Guild Wars 2 is running !
    ping 127.0.0.1 -n 2 >nul 2>&1
    echo. Closing Guild Wars 2 ...
    ping 127.0.0.1 -n 2 >nul 2>&1
    taskkill /f /im %gw2Exe% >nul 2>&1
)
echo. Deleting temporary files ...
for /d %%G in ("%Temp%\gw2cache*") do rd /s /q "%%~G" >nul 2>&1
echo. Deletion completed
ping 127.0.0.1 -n 2 >nul 2>&1
goto Menu

:Guildwars2_Client
cls
echo.
echo. [33m-----------------------------------
echo. Clear the Guild Wars 2 Client Cache
echo. -----------------------------------[30;47m
echo.
echo. [31m/!\ If the game is in use, it will be closed ![30;47m
echo.
echo. This completely erases your personal settings (graphics, sounds, shortcuts).
echo. And put the game back as it was during its first installation.
echo. This can correct problems relating to the Trading Post.
echo. No need to redownload the game files.
echo.
echo. Location of the file :
echo. %APPDATA%\Guild Wars 2\Local.dat
echo.
choice /c YN /m "> Confirm deletion of the client cache file ? "
if %errorlevel% == 1 goto Delete_Client_Cache
if %errorlevel% == 2 goto Menu
:Delete_Client_Cache
echo.
tasklist | findstr /c:%gw2Exe% >nul
if %errorlevel% == 0 (
    echo. Guild Wars 2 is running !
    ping 127.0.0.1 -n 2 >nul 2>&1
    echo. Closing Guild Wars 2 ...
    ping 127.0.0.1 -n 2 >nul 2>&1
    taskkill /f /im %gw2Exe% >nul 2>&1
)
echo. Deleting the client cache file ...
del /Q "%APPDATA%\Guild Wars 2\Local.dat" >nul 2>&1
echo. Deletion completed
ping 127.0.0.1 -n 2 >nul 2>&1
goto Menu

:Guildwars2_Diagnostic
cls
echo.
echo. [33m------------------------------------
echo. Perform a diagnostic of the computer
echo. ------------------------------------[30;47m
echo.
echo. [31m/!\ If the game is in use, it will be closed ![30;47m
echo.
echo. The diagnostic file 'NetworkDiag.log' will be saved in the game folder.
echo. or in the folder : "%USERPROFILE%\Documents\Guild Wars 2".
echo. This file may be requested in certain cases by Guild Wars 2 support.
echo.
choice /c YN /m "> Do you want to start the diagnostic mode ? "
if %errorlevel% == 1 goto Diagnostic
if %errorlevel% == 2 goto Menu
:Diagnostic
tasklist | findstr /c:%gw2Exe% >nul
if %errorlevel% == 0 (
    echo. Guild Wars 2 is running !
    ping 127.0.0.1 -n 2 >nul 2>&1
    echo. Closing Guild Wars 2 ...
    ping 127.0.0.1 -n 2 >nul 2>&1
    taskkill /f /im %gw2Exe% >nul 2>&1
    echo.
    echo. Restarting Guild Wars 2 in Diagnostic Mode ...
    start "Guild Wars 2" "%gw2Path%\%gw2Exe%" -diag
) else (
    echo. Starting Guild Wars 2 in Diagnostic Mode ...
    start "Guild Wars 2" "%gw2Path%\%gw2Exe%" -diag
)
goto Menu

:Guildwars2_Repair
cls
echo.
echo. [33m-----------------------------
echo. Analyze and repair game files
echo. -----------------------------[30;47m
echo.
echo. [31m/!\ If the game is in use, it will be closed ![30;47m
echo.
echo. The game files contained in 'Gw2.dat' will be analyzed to find errors.
echo. Corrupted or missing files will be automatically downloaded.
echo. Do not leave the game client during this procedure!
echo.
choice /c YN /m "> Confirm game data verification and repair ? "
if %errorlevel% == 1 goto Repair
if %errorlevel% == 2 goto Menu
:Repair
tasklist | findstr /c:%gw2Exe% >nul
if %errorlevel% == 0 (
    echo. Guild Wars 2 is running !
    ping 127.0.0.1 -n 2 >nul 2>&1
    echo. Closing Guild Wars 2 ...
    ping 127.0.0.1 -n 2 >nul 2>&1
    taskkill /f /im %gw2Exe% >nul 2>&1
    echo.
    echo. Restarting Guild Wars 2 in Repair Mode ...
    start "Guild Wars 2" "%gw2Path%\%gw2Exe%" -repair
) else (
    echo. Starting Guild Wars 2 in Repair Mode ...
    start "Guild Wars 2" "%gw2Path%\%gw2Exe%" -repair
)
goto Menu

:Close
cls
echo.
echo. Closing the Launcher Wizard ...
echo. Have a nice day (^^^^,)
ping 127.0.0.1 -n 2 >nul 2>&1
exit