REM <#
@echo off
copy GuildWars2_UpdateArcDPS.cmd GuildWars2_UpdateArcDPS.ps1 >NUL
PowerShell.exe -ExecutionPolicy Unrestricted -NoProfile -Command "&{Set-Alias REM Write-Host; .\GuildWars2_UpdateArcDPS.ps1}"
del GuildWars2_UpdateArcDPS.ps1
exit
REM #>


<# ------------------------------
   DO NOT CHANGE BELLOW THIS LINE
   ------------------------------ #>


<# ---- GUILD WARS 2 FOLDER ----
   Write here the full path to the game folder (without the last \ ).
   Need to use "" on this file !
   Here are two common examples:
   $gw2Path = "C:\Program Files (x86)\Guild Wars 2"
   $gw2Path = "D:\Games\Guild Wars 2"
   ----------------------------- #>

$gw2Path = "C:\Program Files (x86)\Guild Wars 2"


<# ---- EXECUTABLE FROM GUILD WARS 2 ----
   Write here the name of the game's executable (without the '.exe' extension)
   This should be the name of the 64-bit version because ArcDps only works in 64 bits!
   -------------------------------------- #>

$gw2Exe = "Gw2-64"


<# ---- ARGUMENTS (OPTIONAL) ----
   Add all the command-line arguments you need here, separated by a comma and enclosed in quotation marks.
   List of available arguments: https://wiki.guildwars2.com/wiki/Command_line_arguments
   Otherwise leave the quotation marks empty.
   ------------------------------ #>

$cmdLine = ""


<# ------------------------------
   DO NOT CHANGE BEYOND THIS LINE
   ------------------------------ #>


<# ---- URLS OF ARCDPS ---- #>
$md5Url   = "https://www.deltaconnected.com/arcdps/x64/d3d9.dll.md5sum"
$d3d9Url  = "https://www.deltaconnected.com/arcdps/x64/d3d9.dll"


<# ---- STARTING GUILD WARS 2 ---- #>
function Start-GW2
{
	Write-Host " "
	Write-Host " Starting Guild Wars 2 ..."
	Start-Sleep -s 2

	if ($cmdLine.Length -lt 1)
	{
		Start-Process -FilePath "$($gw2Path)\$($gw2Exe).exe"
	}
	else
	{
		Start-Process -FilePath "$($gw2Path)\$($gw2Exe).exe" -ArgumentList $cmdLine
	}
}


<# ---- DOWNLOADING ARCDPS ---- #>
function Download-ArcDps
{
	Write-Host " Downloading ArcDps files ..."
	Start-Sleep -s 2

	$d3d9Response = Invoke-WebRequest -Uri $d3d9Url -UseBasicParsing
	Set-Content -Path "$($gw2Path)\bin64\d3d9.dll" -Encoding Byte -Value $d3d9Response.Content

	Write-Host " Installation of ArcDps files completed"
	Start-Sleep -s 2

	Start-GW2
}


<# ---- ARCDPS CONTROL ---- #>
function CheckArcDps
{
	if ((Get-Process $gw2Exe -ErrorAction 0).Count -gt 0)
	{
		Write-Host " Guild Wars 2 is running !"
		Start-Sleep -s 1

		Write-Host " Guild Wars 2 will be closed before continuing."
		Start-Sleep -s 2

		Stop-Process -Name $gw2Exe
		Start-Sleep -s 2
	}

	Write-Host " Verifying the version of ArcDps ..."

	$fileExists = Test-Path "$($gw2Path)\bin64\d3d9.dll"

	if ($fileExists)
	{
		$currD3d9 = Get-FileHash "$($gw2Path)\bin64\d3d9.dll" -Algorithm MD5

		try
		{
			$md5response = Invoke-WebRequest -Uri $md5Url -UseBasicParsing
		}
		catch
		{
			Write-Host " Error: Failed to download MD5 control file." -ForegroundColor Red
			Write-Host " ArcDps has not been installed or updated!" -ForegroundColor Red
			Write-Host " Please try again later ..." -ForegroundColor Red
			Start-Sleep -s 5

			Start-GW2

			Exit
		}

		if (!$currD3d9.Hash.Equals(($md5response.ToString().Split(" ",[System.StringSplitOptions]::RemoveEmptyEntries)[0]), [System.StringComparison]::InvariantCultureIgnoreCase))
		{
			Write-Host " A newer version of ArcDps will be installed ..." -ForegroundColor DarkYellow
			Start-Sleep -s 2

			Write-Host " Backup copy of old files ..."
			Start-Sleep -s 2

			Copy-Item "$($gw2Path)\bin64\d3d9.dll" -Destination "$($gw2Path)\bin64\d3d9.dll.bak" -Force

			Download-ArcDps
		}
		else
		{
			Write-Host " Your version of ArcDps is already up to date !" -ForegroundColor Green
			Start-Sleep -s 2

			Start-GW2
		}
	}
	else
	{
		Download-ArcDps
	}
}


<# ---- SCRIPT EXECUTION ---- #>
CheckArcDps